pub enum CacheInvalidError {
Expired {
msg: String,
},
TooNew {
msg: String,
},
Invalidated,
}Variants
Expired
The cache is too old to use for the current slot.
TooNew
A calculation was attempted for a slot that is too old to use the cache, since the cache was created more recently than the relevant slot.
Invalidated
The cache has been manually invalidated and may no longer be used.